@@ -737,9 +737,15 @@ int parsecmdline (int argc /** argument count */,
 	P(GT_("  -w, --warnings    interval between warning mail notification\n"));
 
 	P(GT_("  -S, --smtphost    set SMTP forwarding host\n"));
+	P(GT_("			   NOTE: all using same name and password!\n"));
 	P(GT_("      --fetchdomains fetch mail for specified domains\n"));
 	P(GT_("  -D, --smtpaddress set SMTP delivery domain to use\n"));
 	P(GT_("      --smtpname    set SMTP full name username@domain\n"));
+	P(GT_("      --esmtpname   override identity used for SMTP AUTH (default: user's name)"));
+	P("\n"); // FIXME: this could have been part of the translated string...
+	P(GT_("      --esmtppassword\n"));
+	P(GT_("			   set secret (password) for SMTP AUTH"));
+	P("\n"); // FIXME: this could have been part of the translated string...
 	P(GT_("  -Z, --antispam    set antispam response values\n"));
 	P(GT_("  -b, --batchlimit  set batch limit for SMTP connections\n"));
 	P(GT_("  -B, --fetchlimit  set fetch limit for server connections\n"));
